Dead code elimination for PTX instruction sequences.
This module implements a fixed-point dead code elimination (DCE) pass. An instruction is dead if it defines a register that is never used by any subsequent instruction and the instruction has no side effects.
Functions
- eliminate_
dead_ code - Remove instructions whose results are never used.